Package: BOBaFIT
Type: Package
Title: Refitting diploid region profiles using a clustering procedure
Version: 1.16.0
Authors@R: c(person("Andrea", "Poletti", email="andrea.poletti5@gmail.com", 
      role=c("aut")),
      person("Gaia", "Mazzocchetti", email="bioinformatic.seragnoli@gmail.com", 
      role=c("aut", "cre")),
      person("Vincenza", "Solli", email="vincenza.solli2@unibo.it", 
      role=c("aut")))
Description: This package provides a method to refit and correct the diploid
 region in copy number profiles. It uses a clustering algorithm to identify
 pathology-specific normal (diploid) chromosomes and then use their copy number
 signal to refit the whole profile.  The package is composed by three functions:
 DRrefit (the main function), ComputeNormalChromosome and PlotCluster.  
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.2
URL: https://github.com/andrea-poletti-unibo/BOBaFIT
BugReports: https://github.com/andrea-poletti-unibo/BOBaFIT/issues
Imports: dplyr, NbClust, ggplot2, ggbio, grDevices, stats, tidyr,
        GenomicRanges, ggforce, stringr, plyranges, methods, utils,
        magrittr
Suggests: rmarkdown, markdown, BiocStyle, knitr, testthat (>= 3.0.0),
        utils, testthat
Config/testthat/edition: 3
biocViews: CopyNumberVariation, Clustering, Visualization,
        Normalization, Software
Depends: R (>= 2.10)
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/BOBaFIT
git_branch: RELEASE_3_23
git_last_commit: 6e021a1
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 20:58:53 UTC; biocbuild
Author: Andrea Poletti [aut],
  Gaia Mazzocchetti [aut, cre],
  Vincenza Solli [aut]
Maintainer: Gaia Mazzocchetti <bioinformatic.seragnoli@gmail.com>
