# Generated by roxygen2: do not edit by hand

export("%>%")
export(DRrefit)
export(DRrefit_plot)
export(PlotChrCluster)
export(Popeye)
export(computeNormalChromosomes)
import(NbClust)
import(ggplot2)
importFrom(GenomicRanges,end)
importFrom(GenomicRanges,makeGRangesFromDataFrame)
importFrom(GenomicRanges,seqnames)
importFrom(GenomicRanges,start)
importFrom(dplyr,arrange)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,n)
importFrom(dplyr,rename)
importFrom(dplyr,summarise)
importFrom(ggbio,geom_segment)
importFrom(ggforce,geom_mark_ellipse)
importFrom(grDevices,dev.off)
importFrom(grDevices,jpeg)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,tiff)
importFrom(magrittr,"%>%")
importFrom(methods,is)
importFrom(plyranges,join_overlap_intersect)
importFrom(stats,median)
importFrom(stats,weighted.mean)
importFrom(stringr,str_sort)
importFrom(tidyr,"%>%")
importFrom(utils,capture.output)
